==> refraction-react-1.0.0.tgz: package/README.md <==
# Refraction React

[![Travis](https://img.shields.io/travis/mbasso/refraction-react.svg?maxAge=2592000)](https://travis-ci.org/mbasso/refraction-react)
[![npm version](https://img.shields.io/npm/v/refraction-react.svg)](https://www.npmjs.com/package/refraction-react)
[![npm downloads](https://img.shields.io/npm/dm/refraction-react.svg?maxAge=2592000)](https://www.npmjs.com/package/refraction-react)
[![Coveralls](https://img.shields.io/coveralls/mbasso/refraction-react.svg?maxAge=2592000)](https://coveralls.io/github/mbasso/refraction-react)

> React bindings for refraction

Official React bindigs for [Refraction](https://github.com/mbasso/refraction). Subscribe, unsubscribe and publish to refraction automatically without doing it manually every time, small and performant!

## Installation

You can install Refraction React using [npm](https://www.npmjs.com/package/refraction-react):

```bash
npm install --save refraction-react
```

If you aren't using npm in your project, you can include RefractionReact using UMD build in the dist folder with `<script>` tag.

## Usage

You can import Refraction React in this way:

```js
import { Provider, connect } from 'refraction-react';
```

Docs is available [here](docs/README.md)

## Examples

You can find an example of Refraction Player in Refraction repository [here](). Alternatively, you can check [awesome-refraction](https://github.com/mbasso/awesome-refraction).

If you want to run examples, check out the instruction [here](https://mbasso.github.com/refraction/docs/introduction/Examples.html).

## Change Log

This project adheres to [Semantic Versioning](http://semver.org/).  
Every release, along with the migration instructions, is documented on the Github [Releases](https://github.com/mbasso/refraction-react/releases) page.

## Authors
**Matteo Basso**
- [github/mbasso](https://github.com/mbasso)
- [@Teo_Basso](https://twitter.com/Teo_Basso)

**Adriano Buscema**
- [github/adribusc](https://github.com/adribusc)

## Copyright and License
Copyright (c) 2016, Matteo Basso.

refraction-react source code is licensed under the [MIT License](https://github.com/mbasso/refraction-react/blob/master/LICENSE.md).

==> refraction-react-1.0.1.tgz: package/README.md <==
# Refraction React

[![Build Status](https://travis-ci.org/mbasso/refraction-react.svg?branch=master)](https://travis-ci.org/mbasso/refraction-react)
[![npm version](https://img.shields.io/npm/v/refraction-react.svg)](https://www.npmjs.com/package/refraction-react)
[![npm downloads](https://img.shields.io/npm/dm/refraction-react.svg?maxAge=2592000)](https://www.npmjs.com/package/refraction-react)
[![Coverage Status](https://coveralls.io/repos/github/mbasso/refraction-react/badge.svg?branch=master)](https://coveralls.io/github/mbasso/refraction-react?branch=master)

> React bindings for refraction

Official React bindigs for [Refraction](https://github.com/mbasso/refraction). Subscribe, unsubscribe and publish to refraction automatically without doing it manually every time, small and performant!

## Installation

You can install Refraction React using [npm](https://www.npmjs.com/package/refraction-react):

```bash
npm install --save refraction-react
```

If you aren't using npm in your project, you can include RefractionReact using UMD build in the dist folder with `<script>` tag.

## Usage

You can import Refraction React in this way:

```js
import { Provider, connect } from 'refraction-react';
```

Docs is available [here](docs/README.md)

## Examples

You can find an example of Refraction Player in Refraction repository [here](). Alternatively, you can check [awesome-refraction](https://github.com/mbasso/awesome-refraction).

If you want to run examples, check out the instruction [here](https://mbasso.github.io/refraction/docs/introduction/Examples.html).

## Change Log

This project adheres to [Semantic Versioning](http://semver.org/).  
Every release, along with the migration instructions, is documented on the Github [Releases](https://github.com/mbasso/refraction-react/releases) page.

## Authors
**Matteo Basso**
- [github/mbasso](https://github.com/mbasso)
- [@Teo_Basso](https://twitter.com/Teo_Basso)

**Adriano Buscema**
- [github/adribusc](https://github.com/adribusc)

## Copyright and License
Copyright (c) 2016, Matteo Basso.

refraction-react source code is licensed under the [MIT License](https://github.com/mbasso/refraction-react/blob/master/LICENSE.md).
